module BaseHullShape() { scale([55, 233, 21]) sphere(50); }
module DriveHollow() {
	scale([21, 144, 21]) cylinder(h = 100, r = 50, center = true);
}
module HullShape() {
	difference() {
		BaseHullShape();
		translate([-2750, 0, 0]) DriveHollow();
		translate([2750, 0, 0]) DriveHollow();
	}
}
module MidshipWindows() { cube([5500, 5500, 100], true); }

module MainHull() {
	difference() {
		HullShape();

		// Gun platforms.
		translate([0, 7200, 750]) cylinder(h = 350, r = 400);
		translate([0, -7200, 750]) cylinder(h = 350, r = 400);
		mirror([0, 0, 1]) {
			translate([0, 7200, 750]) cylinder(h = 350, r = 400);
			translate([0, -7200, 750]) cylinder(h = 350, r = 400);
		}

		translate([0, 0, -600]) MidshipWindows();
		translate([0, 0, 600]) MidshipWindows();
	}
}

module TowerShape() {
	intersection() {
		cube([2100, 2100, 2600], center = true);
		cylinder(r = 1150, h = 2602, center = true);
	}
}

module Tower() {
	module TowerWindows() {
		union() {
			cube([3400, 800, 100], true);
			cube([800, 3400, 100], true);
		}
	}

	union() {
		color("lightsteelblue") difference() {
			TowerShape();
			translate([0, 0, 1100]) TowerWindows();
			translate([0, 0, -1100]) TowerWindows();
		}
		color("orange", alpha = 0.8) scale(0.95) TowerShape();
	}
}

module ReactorHousing() {
	hull() {
		cylinder(r = 400, h = 2200, center = true);
		cylinder(r = 250, h = 2400, center = true);
	}
}

module RippleDrive() {
	module DriveHollow() {
		union() {
			/*cube([1000, 300, 800], true);
			cube([300, 1000, 800], true);*/
			translate([-400, 0, 0]) scale([1.6, 1, 1])
				cylinder(r = 150, h = 800, center = true);
			translate([400, 0, 0]) scale([1.6, 1, 1])
				cylinder(r = 150, h = 800, center = true);
			translate([0, -400, 0]) scale([1, 1.6, 1])
				cylinder(r = 150, h = 800, center = true);
			translate([0, 400, 0]) scale([1, 1.6, 1])
				cylinder(r = 150, h = 800, center = true);
		}
	}

	rotate([90, 0, 0]) union() {
		color("lightsteelblue") difference() {
			hull() {
				cylinder(h = 7200, r = 400, center = true);
				cylinder(h = 8800, r = 250, center = true);
			}

			translate([0, 0, 800]) DriveHollow();
			translate([0, 0, -800]) DriveHollow();
			translate([0, 0, 2400]) DriveHollow();
			translate([0, 0, -2400]) DriveHollow();
		}

		color("hotpink", alpha = 0.8)
			cylinder(h = 8000, r = 250, center = true);
	}
}

module DrivePylon() {
	rotate([0, 90, 0]) cylinder(h = 5000, r = 250, center = true);
}

module LaunchTube() {
	union() {
		difference() {
			intersection() {
				cube([900, 1300, 600], true);
				scale([11, 1, 9])
					rotate([90, 0, 0])
						cylinder(r = 50, h = 2000, center = true);
			}
			cube([800, 1500, 500], true);
		}
		cube([800, 1200, 500], true);
	}
}

module GunTurret() {
	union() {
		difference() {
			//sphere(250);
			scale([0.25, 0.25, 0.15]) TowerShape();
			translate([-150, 0, 0]) cube(300, false);
		}
		translate([-75, 0, 100])
			rotate([-90, 0, 0]) cylinder(h = 500, r = 50);
		translate([75, 0, 100])
			rotate([-90, 0, 0]) cylinder(h = 500, r = 50);
	}
}

module Nightingale() {
	union() {
		color("lightsteelblue") MainHull();
		
		color("orange", alpha = 0.8) {
			translate([0, 0, 600]) scale([0.97, 1, 1])
				intersection() { HullShape(); MidshipWindows(); }
			translate([0, 0, -600]) scale([0.97, 1, 1])
				intersection() { HullShape(); MidshipWindows(); }
		}

		translate([0, -3400, 0]) Tower();

		translate([-2350, 0, 0]) RippleDrive();
		translate([2350, 0, 0]) RippleDrive();

		color("lightsteelblue") {
			DrivePylon();
			translate([0, 1600, 0]) DrivePylon();
			translate([0, -1600, 0]) DrivePylon();
		}

		color("lightsteelblue") {
			translate([-1400, -8500, 0])
				rotate([0, 0, -75])
					LaunchTube();
			translate([1400, -8500, 0])
				rotate([0, 0, 75])
					LaunchTube();
			translate([-1100, -9500, 0])
				rotate([0, 0, -75])
					LaunchTube();
			translate([1100, -9500, 0])
				rotate([0, 0, 75])
					LaunchTube();
		}

		color("lightsteelblue") {
			translate([0, 7200, 800]) GunTurret();
			translate([0, -7200, 800])
				rotate([0, 0, 180])
					GunTurret();
			translate([0, 7200, -800])
				rotate([0, 180, 0])
					GunTurret();
			translate([0, -7200, -800])
				rotate([0, 180, 180])
					GunTurret();
		}

		color("lightsteelblue") {
			translate([650, 650, 0])
				translate([0, 3400, 0])
					ReactorHousing();
			translate([-650, 650, 0])
				translate([0, 3400, 0])
					ReactorHousing();
			translate([650, -650, 0])
				translate([0, 3400, 0])
					ReactorHousing();
			translate([-650, -650, 0])
				translate([0, 3400, 0])
					ReactorHousing();
		}
	}
}

//MainHull();
//Tower();
//RippleDrive();
//LaunchTube();
//GunTurret();

Nightingale();
